==> guile-2.0.11-3-armv7h.pkg.tar.xz: usr/lib/guile/2.0/ccache/oop/goops/simple.go <==
GOOF----LE-4-2.0       ] D 4  hr      ] g  guile	 	g  define-module*	 	 	g  oop	g  goops	g  simple		 	
g  filenameS	f  oop/goops/simple.scm	g  importsS	
g  	accessors	
 	 	 	g  exportsS	g  define-class	 	g  set-current-module	 	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any	g  each-any	 	!g  
syntax-object	"g  $define-class-with-accessors-keywords	#g  top	$# 	%g  ribcage	&g  dummy	'g  arg	(&' 	)g  m-EE2gwIUVPoBBu5kBdo4t49-1316	*)# 	+*$ 	,f  l-EE2gwIUVPoBBu5kBdo4t49-1321	-f  l-EE2gwIUVPoBBu5kBdo4t49-1322	.,- 	/%(+. 	0% 	1g  x	21 	3* 	4f  l-EE2gwIUVPoBBu5kBdo4t49-1318	54 	6%235 	7$/06 	8g  hygiene	98 	:!"79 	;g  syntax-violation	<; 	=; 	>f  -source expression failed to match any pattern	?g  module-use!	@g  module-public-interface	Ag  current-module	Bg  resolve-interface	C C 5 h     ]4	
5 4 >  "  G   4 :  h   >   ]C6       g  dummy
		 g  arg		  			   C=>   h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  oop/goops/simple.scm
	
 		"  g  
macro-typeg  syntax-rulesg  patternsg  argg  ...   C5R?i4@i4Ai5 54BiC56        g  m
		,  g  filenamef  oop/goops/simple.scm		
w		
|		&		
		
		 		
	
 		
   C6 

==> guile-2.0.11-4-armv7h.pkg.tar.xz: usr/lib/guile/2.0/ccache/oop/goops/simple.go <==
GOOF----LE-4-2.0       ] D 4  hr      ] g  guile	 	g  define-module*	 	 	g  oop	g  goops	g  simple		 	
g  filenameS	f  oop/goops/simple.scm	g  importsS	
g  	accessors	
 	 	 	g  exportsS	g  define-class	 	g  set-current-module	 	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any	g  each-any	 	!g  
syntax-object	"g  $define-class-with-accessors-keywords	#g  top	$# 	%g  ribcage	&g  dummy	'g  arg	(&' 	)g  m-hU1ODMjLsp7r6wFdvM0WuN-1316	*)# 	+*$ 	,f  l-hU1ODMjLsp7r6wFdvM0WuN-1321	-f  l-hU1ODMjLsp7r6wFdvM0WuN-1322	.,- 	/%(+. 	0% 	1g  x	21 	3* 	4f  l-hU1ODMjLsp7r6wFdvM0WuN-1318	54 	6%235 	7$/06 	8g  hygiene	98 	:!"79 	;g  syntax-violation	<; 	=; 	>f  -source expression failed to match any pattern	?g  module-use!	@g  module-public-interface	Ag  current-module	Bg  resolve-interface	C C 5 h     ]4	
5 4 >  "  G   4 :  h   >   ]C6       g  dummy
		 g  arg		  			   C=>   h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  oop/goops/simple.scm
	
 		"  g  
macro-typeg  syntax-rulesg  patternsg  argg  ...   C5R?i4@i4Ai5 54BiC56        g  m
		,  g  filenamef  oop/goops/simple.scm		
w		
|		&		
		
		 		
	
 		
   C6 
